import System;
import System.Drawing;
import System.IO;
import System.Reflection;
import System.Windows.Forms;

public class BasicForm extends Form {
    private var mainMenu:System.Windows.Forms.MainMenu;
    private var mnuFile:System.Windows.Forms.MenuItem;
    private var mnuOpen:System.Windows.Forms.MenuItem;
    private var mnuSave:System.Windows.Forms.MenuItem;
    private var mnuExit:System.Windows.Forms.MenuItem;
    
    private var textFile:System.Windows.Forms.TextBox;
    
    private var openDialog:System.Windows.Forms.OpenFileDialog;
    private var saveDialog:System.Windows.Forms.SaveFileDialog;

    public function BasicForm() {
        InitializeComponents();
    }
    
    private function Form_Open(sender:Object, e:EventArgs) : void {
        if ( openDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK ) {
            var sr:StreamReader = new StreamReader(openDialog.FileName);
            this.textFile.Text = sr.ReadToEnd();
            sr.Close();
        }
    }
    
    private function Form_Save(sender:Object, e:EventArgs) : void {
        if ( saveDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK ) {
            var sw:StreamWriter = new StreamWriter(saveDialog.FileName);
            sw.Write(this.textFile.Text);
            sw.Close();
        }
    }

    private function Form_Exit(sender:Object, e:EventArgs) : void {
        this.Close();
    }

    private function InitializeComponents() : void {
        this.Text = "Basic Windows Forms";
        this.Height = 160;
        this.Width = 300;
        this.WindowState = FormWindowState.Normal;
        this.StartPosition = FormStartPosition.CenterScreen;
        
        this.openDialog = new OpenFileDialog();
        this.openDialog.InitialDirectory = Assembly.GetExecutingAssembly().Location;
        this.openDialog.Filter = "Text Files (*.txt)|*.txt|All Files (*.*)|*.*";
        this.openDialog.FilterIndex = 1;
        this.openDialog.RestoreDirectory = true;
        
        this.saveDialog = new SaveFileDialog();
        this.saveDialog.InitialDirectory = Assembly.GetExecutingAssembly().Location;
        this.saveDialog.Filter = "Text Files (*.txt)|*.txt|All Files (*.*)|*.*";
        this.saveDialog.FilterIndex = 1;
        this.saveDialog.RestoreDirectory = true;
        
        this.textFile = new TextBox();
        this.textFile.AcceptsReturn = true;
        this.textFile.Multiline = true;
        this.textFile.Dock = DockStyle.Fill;

        this.mainMenu = new MainMenu();
        
        this.mnuFile = new MenuItem("&File");
        this.mnuOpen = new MenuItem("&Open", this.Form_Open, Shortcut.CtrlO);
        this.mnuSave = new MenuItem("&Save", this.Form_Save, Shortcut.CtrlS);
        this.mnuExit = new MenuItem("E&xit", this.Form_Exit, Shortcut.CtrlX);
        
        this.mainMenu.MenuItems.Add(this.mnuFile);
        this.mnuFile.MenuItems.AddRange(MenuItem[]([this.mnuOpen, this.mnuSave, new MenuItem("-"), this.mnuExit]));
        this.Menu = this.mainMenu;
        
        this.Controls.Add(this.textFile);
    }
    
    public STAThreadAttribute() static function Main(Args:String[]) : void {
        Application.Run(new BasicForm());
    }
}

BasicForm.Main(Environment.GetCommandLineArgs());